@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # Author: Mike McKerns (mmckerns @caltech and @uqfoundation)
-# Copyright (c) 2018-2021 The Uncertainty Quantification Foundation.
+# Copyright (c) 2018-2022 The Uncertainty Quantification Foundation.
 # License: 3-clause BSD.  The full license text is available at:
 #  - https://github.com/uqfoundation/ppft/blob/master/LICENSE
 
@@ -10,7 +10,11 @@ import glob
 import os
 try:
     import pox
-    python = pox.which_python(fullpath=False) or 'python'
+    python = pox.which_python(fullpath=False)
+    if not python:
+        python = 'python'
+    elif not pox.which(python):
+        python = pox.which_python(fullpath=False, version=True)
 except ImportError:
     python = 'python'
 import subprocess as sp
